@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 #
 # Copyright 2023 BredOS
 #
@@ -15,6 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
+
 import faulthandler
 from typing import Any
 
@@ -84,6 +86,9 @@ class BakeryApp(Adw.Application):
     def __init__(self, **kwargs) -> None:
         super().__init__(**kwargs)
         self.connect("activate", self.on_activate)
+        # Force dark mode
+        style_manager = Adw.StyleManager.get_default()
+        style_manager.set_color_scheme(Adw.ColorScheme.FORCE_DARK)
         self.css_provider = self.load_css(script_dir + "/data/main.css")
 
     def on_activate(self, app) -> None:
